@@ -7,15 +7,15 @@ const MIN_INPUT_FIELD_OFFSET_WIDTH = 60;
 const MIN_OPACITY = 0.7;
 const MAX_OPACITY = 1;
 
-let notificationWrapper;
-let notificationTimeout;
-
 const DatabaseState = {
     DISCONNECTED: 0,
     LOCKED: 1,
     UNLOCKED: 2
 };
 
+let notificationWrapper;
+let notificationTimeout;
+
 // jQuery style wrapper for querySelector()
 const $ = function(elem) {
     return document.querySelector(elem);
@@ -40,17 +40,17 @@ class Icon {
                 kpxcUI.updateFromIntersectionObserver(this, entries);
             });
         } catch (err) {
-            console.log(err);
+            logError(err);
         }
     }
 
-    switchIcon(state) {
+    switchIcon(state, uuid) {
         if (!this.icon) {
             return;
         }
 
         if (state === DatabaseState.UNLOCKED) {
-            this.icon.style.filter = 'saturate(100%)';
+            this.icon.style.filter = kpxc.credentials.length === 0 && !uuid ? 'saturate(0%)' : 'saturate(100%)';
         } else {
             this.icon.style.filter = 'saturate(0%)';
         }
@@ -105,6 +105,12 @@ kpxcUI.monitorIconPosition = function(iconClass) {
     window.addEventListener('scroll', function(e) {
         kpxcUI.updateIconPosition(iconClass);
     });
+
+    window.addEventListener('transitionend', function(e) {
+        if (e.target && (e.target.nodeName === 'INPUT' || e.target.nodeName === 'TEXTAREA')) {
+            kpxcUI.updateIconPosition(iconClass);
+        }
+    });
 };
 
 kpxcUI.updateIconPosition = function(iconClass) {
@@ -122,14 +128,21 @@ kpxcUI.setIconPosition = function(icon, field, rtl = false, segmented = false) {
     const rect = field.getBoundingClientRect();
     const size = Number(icon.getAttribute('size'));
     const offset = kpxcUI.calculateIconOffset(field, size);
-    let left = kpxcUI.bodyStyle.position.toLowerCase() === 'relative' ? rect.left - kpxcUI.bodyRect.left : rect.left;
-    const top = kpxcUI.bodyStyle.position.toLowerCase() === 'relative' ? rect.top - kpxcUI.bodyRect.top : rect.top;
+    let left = kpxcUI.getRelativeLeftPosition(rect);
+    let top = kpxcUI.getRelativeTopPosition(rect);
 
     // Add more space for the icon to show it at the right side of the field if TOTP fields are segmented
     if (segmented) {
         left += size + 10;
     }
 
+    // Adjusts the icon offset for certain sites
+    const iconOffset = kpxcSites.iconOffset(left, top, size);
+    if (iconOffset) {
+        left = iconOffset[0];
+        top = iconOffset[1];
+    }
+
     const scrollTop = document.scrollingElement ? document.scrollingElement.scrollTop : 0;
     const scrollLeft = document.scrollingElement ? document.scrollingElement.scrollLeft : 0;
     icon.style.top = Pixels(top + scrollTop + offset + 1);
@@ -138,6 +151,14 @@ kpxcUI.setIconPosition = function(icon, field, rtl = false, segmented = false) {
                     : Pixels(left + scrollLeft + field.offsetWidth - size - offset);
 };
 
+kpxcUI.getRelativeLeftPosition = function(rect) {
+    return kpxcUI.bodyStyle.position.toLowerCase() === 'relative' ? rect.left - kpxcUI.bodyRect.left : rect.left;
+};
+
+kpxcUI.getRelativeTopPosition = function(rect) {
+    return kpxcUI.bodyStyle.position.toLowerCase() === 'relative' ? rect.top - kpxcUI.bodyRect.top : rect.top;
+};
+
 kpxcUI.deleteHiddenIcons = function(iconList, attr) {
     const deletedIcons = [];
     for (const icon of iconList) {
@@ -210,6 +231,8 @@ kpxcUI.createNotification = function(type, message) {
         return;
     }
 
+    logDebug(message);
+
     const notification = kpxcUI.createElement('div', 'kpxc-notification kpxc-notification-' + type, {});
     type = type.charAt(0).toUpperCase() + type.slice(1) + '!';
 
@@ -251,6 +274,12 @@ kpxcUI.createNotification = function(type, message) {
     }, 5000);
 };
 
+kpxcUI.createButton = function(color, textContent, callback) {
+    const button = kpxcUI.createElement('button', color, {}, textContent);
+    button.addEventListener('click', callback);
+    return button;
+};
+
 const DOMRectToArray = function(domRect) {
     return [ domRect.bottom, domRect.height, domRect.left, domRect.right, domRect.top, domRect.width, domRect.x, domRect.y ];
 };
@@ -258,8 +287,11 @@ const DOMRectToArray = function(domRect) {
 const initColorTheme = function(elem) {
     const colorTheme = kpxc.settings['colorTheme'];
 
-    if (colorTheme === undefined || colorTheme === 'system') {
+    if (colorTheme === undefined) {
         elem.removeAttribute('data-color-theme');
+    } else if (colorTheme === 'system') {
+        const theme = window.matchMedia('(prefers-color-scheme: dark)').matches ? 'dark' : 'light';
+        elem.setAttribute('data-color-theme', theme);
     } else {
         elem.setAttribute('data-color-theme', colorTheme);
     }
@@ -272,6 +304,12 @@ const createStylesheet = function(file) {
     return stylesheet;
 };
 
+const logDebug = function(message, extra) {
+    if (kpxc.settings.debugLogging) {
+        debugLogMessage(message, extra);
+    }
+};
+
 // Enables dragging
 document.addEventListener('mousemove', function(e) {
     if (!kpxcUI.mouseDown) {
@@ -287,16 +325,6 @@ document.addEventListener('mousemove', function(e) {
             kpxcPasswordDialog.dialog.style.top = Pixels(yPos);
         }
     }
-
-    if (kpxcDefine.selected === kpxcDefine.dialog) {
-        const xPos = e.clientX - kpxcDefine.diffX;
-        const yPos = e.clientY - kpxcDefine.diffY;
-
-        if (kpxcDefine.selected && kpxcDefine.dialog) {
-            kpxcDefine.dialog.style.left = Pixels(xPos);
-            kpxcDefine.dialog.style.top = Pixels(yPos);
-        }
-    }
 });
 
 document.addEventListener('mousedown', function(e) {
@@ -313,7 +341,6 @@ document.addEventListener('mouseup', function(e) {
     }
 
     kpxcPasswordDialog.selected = null;
-    kpxcDefine.selected = null;
     kpxcUI.mouseDown = false;
 });
 
@@ -332,7 +359,7 @@ Element.prototype.attachShadow = function () {
     try {
         return this._attachShadow({ mode: 'closed' });
     } catch (e) {
-        console.log('Error: ', e);
+        logError(e);
     }
 };
 
