@@ -123,14 +123,10 @@ const iconClicked = async function(field, icon) {
         return;
     }
 
-    // Try to reconnect if KeePassXC is not currently connected
-    const connected = await sendMessage('is_connected');
+    // Try to reconnect if KeePassXC for the case we're not currently connected
+    const connected = await kpxc.reconnect();
     if (!connected) {
-        const reconnectResponse = await sendMessage('reconnect');
-        if (!reconnectResponse.keePassXCAvailable) {
-            kpxcUI.createNotification('error', tr('errorNotConnected'));
-            return;
-        }
+        return;
     }
 
     const databaseHash = await sendMessage('check_database_hash');
